"""用户信息验证"""

from ...base import BaseRequest


class BankCardFourAuthVerifyRequest(BaseRequest):
    """
    银行卡四要素鉴权请求（下发短信验证码）请求

    :type card_no: string
    :param card_no: 银行卡号

    :type id_card: string
    :param id_card: 身份证号码

    :type real_name: string
    :param real_name: 姓名

    :type mobile: string
    :param mobile: 银行预留手机号
    """
    def __init__(
        self,
        card_no=None,
        id_card=None,
        real_name=None,
        mobile=None
    ):
        super().__init__()
        self.card_no = card_no
        self.id_card = id_card
        self.real_name = real_name
        self.mobile = mobile


class BankCardFourAuthVerifyResponse(BaseRequest):
    """
    银行卡四要素鉴权请求（下发短信验证码）返回

    :type ref: string
    :param ref: 交易凭证
    """
    def __init__(
        self,
        ref=None
    ):
        super().__init__()
        self.ref = ref


class BankCardFourAuthConfirmRequest(BaseRequest):
    """
    银行卡四要素确认请求（上传短信验证码）请求

    :type card_no: string
    :param card_no: 银行卡号

    :type id_card: string
    :param id_card: 身份证号码

    :type real_name: string
    :param real_name: 姓名

    :type mobile: string
    :param mobile: 银行预留手机号

    :type captcha: string
    :param captcha: 短信验证码

    :type ref: string
    :param ref: 交易凭证
    """
    def __init__(
        self,
        card_no=None,
        id_card=None,
        real_name=None,
        mobile=None,
        captcha=None,
        ref=None
    ):
        super().__init__()
        self.card_no = card_no
        self.id_card = id_card
        self.real_name = real_name
        self.mobile = mobile
        self.captcha = captcha
        self.ref = ref


class BankCardFourAuthConfirmResponse(BaseRequest):
    """
    银行卡四要素确认请求（上传短信验证码）返回
    """


class BankCardFourVerifyRequest(BaseRequest):
    """
    银行卡四要素验证请求

    :type card_no: string
    :param card_no: 银行卡号

    :type id_card: string
    :param id_card: 身份证号码

    :type real_name: string
    :param real_name: 姓名

    :type mobile: string
    :param mobile: 银行预留手机号
    """
    def __init__(
        self,
        card_no=None,
        id_card=None,
        real_name=None,
        mobile=None
    ):
        super().__init__()
        self.card_no = card_no
        self.id_card = id_card
        self.real_name = real_name
        self.mobile = mobile


class BankCardFourVerifyResponse(BaseRequest):
    """
    银行卡四要素验证返回
    """


class BankCardThreeVerifyRequest(BaseRequest):
    """
    银行卡三要素验证请求

    :type card_no: string
    :param card_no: 银行卡号

    :type id_card: string
    :param id_card: 身份证号码

    :type real_name: string
    :param real_name: 姓名
    """
    def __init__(
        self,
        card_no=None,
        id_card=None,
        real_name=None
    ):
        super().__init__()
        self.card_no = card_no
        self.id_card = id_card
        self.real_name = real_name


class BankCardThreeVerifyResponse(BaseRequest):
    """
    银行卡三要素验证返回
    """


class IDCardVerifyRequest(BaseRequest):
    """
    身份证实名验证请求

    :type id_card: string
    :param id_card: 身份证号码

    :type real_name: string
    :param real_name: 姓名
    """
    def __init__(
        self,
        id_card=None,
        real_name=None
    ):
        super().__init__()
        self.id_card = id_card
        self.real_name = real_name


class IDCardVerifyResponse(BaseRequest):
    """
    身份证实名验证返回
    """


class UserExemptedInfoRequest(BaseRequest):
    """
    上传免验证用户名单信息请求

    :type card_type: string
    :param card_type: 证件类型码

    :type id_card: string
    :param id_card: 证件号码

    :type real_name: string
    :param real_name: 姓名

    :type comment_apply: string
    :param comment_apply: 申请备注

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type user_images: list
    :param user_images: 人员信息图片

    :type country: string
    :param country: 国别（地区）代码

    :type birthday: string
    :param birthday: 出生日期

    :type gender: string
    :param gender: 性别

    :type notify_url: string
    :param notify_url: 回调地址

    :type ref: string
    :param ref: 请求流水号
    """
    def __init__(
        self,
        card_type=None,
        id_card=None,
        real_name=None,
        comment_apply=None,
        broker_id=None,
        dealer_id=None,
        user_images=None,
        country=None,
        birthday=None,
        gender=None,
        notify_url=None,
        ref=None
    ):
        super().__init__()
        self.card_type = card_type
        self.id_card = id_card
        self.real_name = real_name
        self.comment_apply = comment_apply
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.user_images = user_images
        self.country = country
        self.birthday = birthday
        self.gender = gender
        self.notify_url = notify_url
        self.ref = ref


class UserExemptedInfoResponse(BaseRequest):
    """
    上传免验证用户名单信息返回

    :type ok: string
    :param ok: 是否上传成功
    """
    def __init__(
        self,
        ok=None
    ):
        super().__init__()
        self.ok = ok


class NotifyUserExemptedInfoRequest(BaseRequest):
    """
    上传免验证用户名单信息审核结果通知

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 证件号

    :type status: string
    :param status: 审核状态

    :type ref: string
    :param ref: 流水号

    :type comment: string
    :param comment: 审核信息
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None,
        real_name=None,
        id_card=None,
        status=None,
        ref=None,
        comment=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.real_name = real_name
        self.id_card = id_card
        self.status = status
        self.ref = ref
        self.comment = comment


class UserWhiteCheckRequest(BaseRequest):
    """
    查看免验证用户名单是否存在请求

    :type id_card: string
    :param id_card: 证件号码

    :type real_name: string
    :param real_name: 姓名
    """
    def __init__(
        self,
        id_card=None,
        real_name=None
    ):
        super().__init__()
        self.id_card = id_card
        self.real_name = real_name


class UserWhiteCheckResponse(BaseRequest):
    """
    查看免验证用户名单是否存在返回

    :type ok: bool
    :param ok: 
    """
    def __init__(
        self,
        ok=None
    ):
        super().__init__()
        self.ok = ok


class GetBankCardInfoRequest(BaseRequest):
    """
    银行卡信息查询请求

    :type card_no: string
    :param card_no: 银行卡号

    :type bank_name: string
    :param bank_name: 银行名称
    """
    def __init__(
        self,
        card_no=None,
        bank_name=None
    ):
        super().__init__()
        self.card_no = card_no
        self.bank_name = bank_name


class GetBankCardInfoResponse(BaseRequest):
    """
    银行卡信息查询返回

    :type bank_code: string
    :param bank_code: 银行代码

    :type bank_name: string
    :param bank_name: 银行名称

    :type card_type: string
    :param card_type: 卡类型

    :type is_support: bool
    :param is_support: 云账户是否支持向该银行支付
    """
    def __init__(
        self,
        bank_code=None,
        bank_name=None,
        card_type=None,
        is_support=None
    ):
        super().__init__()
        self.bank_code = bank_code
        self.bank_name = bank_name
        self.card_type = card_type
        self.is_support = is_support



"""实时支付"""

from .model.payment import *
from ..base import BaseClient
from ...utils import Utils


class PaymentClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)

    def create_bankpay_order(self, request: CreateBankpayOrderRequest):
        """ 银行卡实时支付

        :type request: CreateBankpayOrderRequest
        :param request: the CreateBankpayOrderRequest request parameters class.

        :return: CreateBankpayOrderResponse
        """
        return self._post(
            "/api/payment/v1/order-bankpay",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def create_alipay_order(self, request: CreateAlipayOrderRequest):
        """ 支付宝实时支付

        :type request: CreateAlipayOrderRequest
        :param request: the CreateAlipayOrderRequest request parameters class.

        :return: CreateAlipayOrderResponse
        """
        return self._post(
            "/api/payment/v1/order-alipay",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def create_wxpay_order(self, request: CreateWxpayOrderRequest):
        """ 微信实时支付

        :type request: CreateWxpayOrderRequest
        :param request: the CreateWxpayOrderRequest request parameters class.

        :return: CreateWxpayOrderResponse
        """
        return self._post(
            "/api/payment/v1/order-wxpay",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_order(self, request: GetOrderRequest):
        """ 查询单笔订单信息

        :type request: GetOrderRequest
        :param request: the GetOrderRequest request parameters class.

        :return: GetOrderResponse
        """
        return self._get(
            "/api/payment/v1/query-order",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_dealer_va_recharge_account(self, request: GetDealerVARechargeAccountRequest):
        """ 查询平台企业汇款信息

        :type request: GetDealerVARechargeAccountRequest
        :param request: the GetDealerVARechargeAccountRequest request parameters class.

        :return: GetDealerVARechargeAccountResponse
        """
        return self._get(
            "/api/payment/v1/va-account",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def list_account(self, request: ListAccountRequest):
        """ 查询平台企业余额

        :type request: ListAccountRequest
        :param request: the ListAccountRequest request parameters class.

        :return: ListAccountResponse
        """
        return self._get(
            "/api/payment/v1/query-accounts",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_ele_receipt_file(self, request: GetEleReceiptFileRequest):
        """ 查询电子回单

        :type request: GetEleReceiptFileRequest
        :param request: the GetEleReceiptFileRequest request parameters class.

        :return: GetEleReceiptFileResponse
        """
        return self._get(
            "/api/payment/v1/receipt/file",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def cancel_order(self, request: CancelOrderRequest):
        """ 取消待支付订单

        :type request: CancelOrderRequest
        :param request: the CancelOrderRequest request parameters class.

        :return: CancelOrderResponse
        """
        return self._post(
            "/api/payment/v1/order/fail",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def create_batch_order(self, request: CreateBatchOrderRequest):
        """ 批次下单

        :type request: CreateBatchOrderRequest
        :param request: the CreateBatchOrderRequest request parameters class.

        :return: CreateBatchOrderResponse
        """
        return self._post(
            "/api/payment/v1/order-batch",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def confirm_batch_order(self, request: ConfirmBatchOrderRequest):
        """ 批次确认

        :type request: ConfirmBatchOrderRequest
        :param request: the ConfirmBatchOrderRequest request parameters class.

        :return: ConfirmBatchOrderResponse
        """
        return self._post(
            "/api/payment/v1/confirm-batch",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )



"""云账户新经济 H5"""

from ...base import BaseRequest


class H5GetStartUrlRequest(BaseRequest):
    """
    预启动请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_user_id: string
    :param dealer_user_id: 平台企业端的用户 ID

    :type client_type: int
    :param client_type: 客户端类型

    :type notify_url: string
    :param notify_url: 异步通知 URL

    :type color: string
    :param color: H5 页面主题颜色

    :type return_url: string
    :param return_url: 跳转 URL

    :type customer_title: int
    :param customer_title: H5 页面 Title
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None,
        dealer_user_id=None,
        client_type=None,
        notify_url=None,
        color=None,
        return_url=None,
        customer_title=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.dealer_user_id = dealer_user_id
        self.client_type = client_type
        self.notify_url = notify_url
        self.color = color
        self.return_url = return_url
        self.customer_title = customer_title


class H5GetStartUrlResponse(BaseRequest):
    """
    预启动返回

    :type h5_url: string
    :param h5_url: 跳转 URL
    """
    def __init__(
        self,
        h5_url=None
    ):
        super().__init__()
        self.h5_url = h5_url


class H5EcoCityAicStatusRequest(BaseRequest):
    """
    查询个体工商户状态请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_user_id: string
    :param dealer_user_id: 平台企业端的用户 ID

    :type id_card: string
    :param id_card: 身份证号码

    :type real_name: string
    :param real_name: 姓名

    :type open_id: string
    :param open_id: 用户唯一标识
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None,
        dealer_user_id=None,
        id_card=None,
        real_name=None,
        open_id=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.dealer_user_id = dealer_user_id
        self.id_card = id_card
        self.real_name = real_name
        self.open_id = open_id


class H5EcoCityAicStatusResponse(BaseRequest):
    """
    查询个体工商户状态返回

    :type status: int
    :param status: 用户签约状态

    :type status_message: string
    :param status_message: 注册状态描述

    :type status_detail: int
    :param status_detail: 注册详情状态码

    :type status_detail_message: string
    :param status_detail_message: 注册详情状态码描述

    :type applyed_at: string
    :param applyed_at: 注册发起时间

    :type registed_at: string
    :param registed_at: 注册完成时间

    :type uscc: string
    :param uscc: 统一社会信用代码

    :type id_card: string
    :param id_card: 身份证号码

    :type real_name: string
    :param real_name: 姓名
    """
    def __init__(
        self,
        status=None,
        status_message=None,
        status_detail=None,
        status_detail_message=None,
        applyed_at=None,
        registed_at=None,
        uscc=None,
        id_card=None,
        real_name=None
    ):
        super().__init__()
        self.status = status
        self.status_message = status_message
        self.status_detail = status_detail
        self.status_detail_message = status_detail_message
        self.applyed_at = applyed_at
        self.registed_at = registed_at
        self.uscc = uscc
        self.id_card = id_card
        self.real_name = real_name


class NotifyH5EcoCityAicRequest(BaseRequest):
    """
    结果回调

    :type open_id: string
    :param open_id: 用户唯一标识

    :type dealer_user_id: string
    :param dealer_user_id: 平台企业端的用户 ID

    :type submit_at: string
    :param submit_at: 注册/注销提交时间

    :type registed_at: string
    :param registed_at: 注册/注销完成时间

    :type status: int
    :param status: 用户签约状态

    :type status_message: string
    :param status_message: 注册状态描述

    :type status_detail: int
    :param status_detail: 注册详情状态码

    :type status_detail_message: string
    :param status_detail_message: 注册详情状态码描述

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type uscc: string
    :param uscc: 统一社会信用代码

    :type id_card: string
    :param id_card: 身份证号码

    :type real_name: string
    :param real_name: 姓名

    :type type: int
    :param type: 回调类型
    """
    def __init__(
        self,
        open_id=None,
        dealer_user_id=None,
        submit_at=None,
        registed_at=None,
        status=None,
        status_message=None,
        status_detail=None,
        status_detail_message=None,
        dealer_id=None,
        broker_id=None,
        uscc=None,
        id_card=None,
        real_name=None,
        type=None
    ):
        super().__init__()
        self.open_id = open_id
        self.dealer_user_id = dealer_user_id
        self.submit_at = submit_at
        self.registed_at = registed_at
        self.status = status
        self.status_message = status_message
        self.status_detail = status_detail
        self.status_detail_message = status_detail_message
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.uscc = uscc
        self.id_card = id_card
        self.real_name = real_name
        self.type = type



"""实时支付"""

from ...base import BaseRequest


class CreateBankpayOrderRequest(BaseRequest):
    """
    银行卡实时支付请求

    :type order_id: string
    :param order_id: 平台企业订单号

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type real_name: string
    :param real_name: 姓名

    :type card_no: string
    :param card_no: 银行卡号

    :type id_card: string
    :param id_card: 身份证号码

    :type phone_no: string
    :param phone_no: 手机号

    :type pay: string
    :param pay: 订单金额

    :type pay_remark: string
    :param pay_remark: 订单备注

    :type notify_url: string
    :param notify_url: 回调地址

    :type project_id: string
    :param project_id: 项目标识
    """
    def __init__(
        self,
        order_id=None,
        dealer_id=None,
        broker_id=None,
        real_name=None,
        card_no=None,
        id_card=None,
        phone_no=None,
        pay=None,
        pay_remark=None,
        notify_url=None,
        project_id=None
    ):
        super().__init__()
        self.order_id = order_id
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.real_name = real_name
        self.card_no = card_no
        self.id_card = id_card
        self.phone_no = phone_no
        self.pay = pay
        self.pay_remark = pay_remark
        self.notify_url = notify_url
        self.project_id = project_id


class CreateBankpayOrderResponse(BaseRequest):
    """
    银行卡实时支付返回

    :type order_id: string
    :param order_id: 

    :type ref: string
    :param ref: 综合服务平台流水号

    :type pay: string
    :param pay: 订单金额
    """
    def __init__(
        self,
        order_id=None,
        ref=None,
        pay=None
    ):
        super().__init__()
        self.order_id = order_id
        self.ref = ref
        self.pay = pay


class CreateAlipayOrderRequest(BaseRequest):
    """
    支付宝实时支付请求

    :type order_id: string
    :param order_id: 平台企业订单号

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type real_name: string
    :param real_name: 姓名

    :type card_no: string
    :param card_no: 支付宝账户

    :type id_card: string
    :param id_card: 身份证号码

    :type phone_no: string
    :param phone_no: 手机号

    :type pay: string
    :param pay: 订单金额

    :type pay_remark: string
    :param pay_remark: 订单备注

    :type notify_url: string
    :param notify_url: 回调地址

    :type project_id: string
    :param project_id: 项目标识

    :type check_name: string
    :param check_name: 校验支付宝账户姓名，固定值：Check
    """
    def __init__(
        self,
        order_id=None,
        dealer_id=None,
        broker_id=None,
        real_name=None,
        card_no=None,
        id_card=None,
        phone_no=None,
        pay=None,
        pay_remark=None,
        notify_url=None,
        project_id=None,
        check_name=None
    ):
        super().__init__()
        self.order_id = order_id
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.real_name = real_name
        self.card_no = card_no
        self.id_card = id_card
        self.phone_no = phone_no
        self.pay = pay
        self.pay_remark = pay_remark
        self.notify_url = notify_url
        self.project_id = project_id
        self.check_name = check_name


class CreateAlipayOrderResponse(BaseRequest):
    """
    支付宝实时支付返回

    :type order_id: string
    :param order_id: 平台企业订单号

    :type ref: string
    :param ref: 综合服务平台流水号

    :type pay: string
    :param pay: 订单金额
    """
    def __init__(
        self,
        order_id=None,
        ref=None,
        pay=None
    ):
        super().__init__()
        self.order_id = order_id
        self.ref = ref
        self.pay = pay


class CreateWxpayOrderRequest(BaseRequest):
    """
    微信实时支付请求

    :type order_id: string
    :param order_id: 平台企业订单号

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type real_name: string
    :param real_name: 姓名

    :type openid: string
    :param openid: 微信用户 openid

    :type id_card: string
    :param id_card: 身份证号码

    :type phone_no: string
    :param phone_no: 手机号

    :type pay: string
    :param pay: 订单金额

    :type pay_remark: string
    :param pay_remark: 订单备注

    :type notify_url: string
    :param notify_url: 回调地址

    :type wx_app_id: string
    :param wx_app_id: 平台企业微信 AppID

    :type wxpay_mode: string
    :param wxpay_mode: 微信支付模式，固定值：transfer

    :type project_id: string
    :param project_id: 项目标识

    :type notes: string
    :param notes: 描述信息，该字段已废弃
    """
    def __init__(
        self,
        order_id=None,
        dealer_id=None,
        broker_id=None,
        real_name=None,
        openid=None,
        id_card=None,
        phone_no=None,
        pay=None,
        pay_remark=None,
        notify_url=None,
        wx_app_id=None,
        wxpay_mode=None,
        project_id=None,
        notes=None
    ):
        super().__init__()
        self.order_id = order_id
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.real_name = real_name
        self.openid = openid
        self.id_card = id_card
        self.phone_no = phone_no
        self.pay = pay
        self.pay_remark = pay_remark
        self.notify_url = notify_url
        self.wx_app_id = wx_app_id
        self.wxpay_mode = wxpay_mode
        self.project_id = project_id
        self.notes = notes


class CreateWxpayOrderResponse(BaseRequest):
    """
    微信实时支付返回

    :type order_id: string
    :param order_id: 平台企业订单号

    :type ref: string
    :param ref: 综合服务平台流水号，唯一

    :type pay: string
    :param pay: 订单金额
    """
    def __init__(
        self,
        order_id=None,
        ref=None,
        pay=None
    ):
        super().__init__()
        self.order_id = order_id
        self.ref = ref
        self.pay = pay


class GetOrderRequest(BaseRequest):
    """
    查询单笔订单信息请求

    :type order_id: string
    :param order_id: 平台企业订单号

    :type channel: string
    :param channel: 支付路径名，银行卡（默认）、支付宝、微信

    :type data_type: string
    :param data_type: 数据类型，如果为 encryption，则对返回的 data 进行加密
    """
    def __init__(
        self,
        order_id=None,
        channel=None,
        data_type=None
    ):
        super().__init__()
        self.order_id = order_id
        self.channel = channel
        self.data_type = data_type


class GetOrderResponse(BaseRequest):
    """
    查询单笔订单信息返回

    :type order_id: string
    :param order_id: 平台企业订单号

    :type pay: string
    :param pay: 订单金额

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type real_name: string
    :param real_name: 姓名

    :type card_no: string
    :param card_no: 收款人账号

    :type id_card: string
    :param id_card: 身份证号码

    :type phone_no: string
    :param phone_no: 手机号

    :type status: string
    :param status: 订单状态码

    :type status_detail: string
    :param status_detail: 订单详细状态码

    :type status_message: string
    :param status_message: 订单状态码描述

    :type status_detail_message: string
    :param status_detail_message: 订单详细状态码描述

    :type broker_amount: string
    :param broker_amount: 综合服务主体支付金额

    :type ref: string
    :param ref: 综合服务平台流水号

    :type broker_bank_bill: string
    :param broker_bank_bill: 支付交易流水号

    :type withdraw_platform: string
    :param withdraw_platform: 支付路径

    :type created_at: string
    :param created_at: 订单接收时间，精确到秒

    :type finished_time: string
    :param finished_time: 订单完成时间，精确到秒

    :type broker_fee: string
    :param broker_fee: 综合服务主体加成服务费

    :type broker_real_fee: string
    :param broker_real_fee: 余额账户支出加成服务费

    :type broker_deduct_fee: string
    :param broker_deduct_fee: 抵扣账户支出加成服务费

    :type pay_remark: string
    :param pay_remark: 订单备注

    :type user_fee: string
    :param user_fee: 用户加成服务费

    :type bank_name: string
    :param bank_name: 银行名称

    :type project_id: string
    :param project_id: 项目标识

    :type anchor_id: string
    :param anchor_id: 新就业形态劳动者 ID，该字段已废弃

    :type notes: string
    :param notes: 描述信息，该字段已废弃

    :type sys_amount: string
    :param sys_amount: 系统支付金额，该字段已废弃

    :type tax: string
    :param tax: 税费，该字段已废弃

    :type sys_fee: string
    :param sys_fee: 系统支付费用，该字段已废弃
    """
    def __init__(
        self,
        order_id=None,
        pay=None,
        broker_id=None,
        dealer_id=None,
        real_name=None,
        card_no=None,
        id_card=None,
        phone_no=None,
        status=None,
        status_detail=None,
        status_message=None,
        status_detail_message=None,
        broker_amount=None,
        ref=None,
        broker_bank_bill=None,
        withdraw_platform=None,
        created_at=None,
        finished_time=None,
        broker_fee=None,
        broker_real_fee=None,
        broker_deduct_fee=None,
        pay_remark=None,
        user_fee=None,
        bank_name=None,
        project_id=None,
        anchor_id=None,
        notes=None,
        sys_amount=None,
        tax=None,
        sys_fee=None
    ):
        super().__init__()
        self.order_id = order_id
        self.pay = pay
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.real_name = real_name
        self.card_no = card_no
        self.id_card = id_card
        self.phone_no = phone_no
        self.status = status
        self.status_detail = status_detail
        self.status_message = status_message
        self.status_detail_message = status_detail_message
        self.broker_amount = broker_amount
        self.ref = ref
        self.broker_bank_bill = broker_bank_bill
        self.withdraw_platform = withdraw_platform
        self.created_at = created_at
        self.finished_time = finished_time
        self.broker_fee = broker_fee
        self.broker_real_fee = broker_real_fee
        self.broker_deduct_fee = broker_deduct_fee
        self.pay_remark = pay_remark
        self.user_fee = user_fee
        self.bank_name = bank_name
        self.project_id = project_id
        self.anchor_id = anchor_id
        self.notes = notes
        self.sys_amount = sys_amount
        self.tax = tax
        self.sys_fee = sys_fee


class GetDealerVARechargeAccountRequest(BaseRequest):
    """
    查询平台企业汇款信息请求

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id


class GetDealerVARechargeAccountResponse(BaseRequest):
    """
    查询平台企业汇款信息返回

    :type acct_name: string
    :param acct_name: 账户名称

    :type acct_no: string
    :param acct_no: 专属账户

    :type bank_name: string
    :param bank_name: 银行名称

    :type dealer_acct_name: string
    :param dealer_acct_name: 付款账户
    """
    def __init__(
        self,
        acct_name=None,
        acct_no=None,
        bank_name=None,
        dealer_acct_name=None
    ):
        super().__init__()
        self.acct_name = acct_name
        self.acct_no = acct_no
        self.bank_name = bank_name
        self.dealer_acct_name = dealer_acct_name


class CancelOrderRequest(BaseRequest):
    """
    取消待支付订单请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type order_id: string
    :param order_id: 平台企业订单号

    :type ref: string
    :param ref: 综合服务平台流水号

    :type channel: string
    :param channel: 支付路径名，银行卡（默认）、支付宝、微信
    """
    def __init__(
        self,
        dealer_id=None,
        order_id=None,
        ref=None,
        channel=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.order_id = order_id
        self.ref = ref
        self.channel = channel


class CancelOrderResponse(BaseRequest):
    """
    取消待支付订单返回

    :type ok: string
    :param ok: 
    """
    def __init__(
        self,
        ok=None
    ):
        super().__init__()
        self.ok = ok


class ListAccountRequest(BaseRequest):
    """
    查询平台企业余额请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    """
    def __init__(
        self,
        dealer_id=None
    ):
        super().__init__()
        self.dealer_id = dealer_id


class ListAccountResponse(BaseRequest):
    """
    查询平台企业余额返回

    :type dealer_infos: list
    :param dealer_infos: 
    """
    def __init__(
        self,
        dealer_infos=None
    ):
        super().__init__()
        self.dealer_infos = dealer_infos


class AccountInfo(BaseRequest):
    """
    账户信息

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type bank_card_balance: string
    :param bank_card_balance: 银行卡余额

    :type is_bank_card: bool
    :param is_bank_card: 是否开通银行卡支付路径

    :type alipay_balance: string
    :param alipay_balance: 支付宝余额

    :type is_alipay: bool
    :param is_alipay: 是否开通支付宝支付路径

    :type wxpay_balance: string
    :param wxpay_balance: 微信余额

    :type is_wxpay: bool
    :param is_wxpay: 是否开通微信支付路径

    :type rebate_fee_balance: string
    :param rebate_fee_balance: 加成服务费返点余额

    :type acct_balance: string
    :param acct_balance: 业务服务费余额

    :type total_balance: string
    :param total_balance: 总余额
    """
    def __init__(
        self,
        broker_id=None,
        bank_card_balance=None,
        is_bank_card=None,
        alipay_balance=None,
        is_alipay=None,
        wxpay_balance=None,
        is_wxpay=None,
        rebate_fee_balance=None,
        acct_balance=None,
        total_balance=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.bank_card_balance = bank_card_balance
        self.is_bank_card = is_bank_card
        self.alipay_balance = alipay_balance
        self.is_alipay = is_alipay
        self.wxpay_balance = wxpay_balance
        self.is_wxpay = is_wxpay
        self.rebate_fee_balance = rebate_fee_balance
        self.acct_balance = acct_balance
        self.total_balance = total_balance


class GetEleReceiptFileRequest(BaseRequest):
    """
    查询电子回单请求

    :type order_id: string
    :param order_id: 平台企业订单号

    :type ref: string
    :param ref: 综合服务平台流水号
    """
    def __init__(
        self,
        order_id=None,
        ref=None
    ):
        super().__init__()
        self.order_id = order_id
        self.ref = ref


class GetEleReceiptFileResponse(BaseRequest):
    """
    查询电子回单返回

    :type expire_time: string
    :param expire_time: 链接失效时间

    :type file_name: string
    :param file_name: 回单名

    :type url: string
    :param url: 下载链接
    """
    def __init__(
        self,
        expire_time=None,
        file_name=None,
        url=None
    ):
        super().__init__()
        self.expire_time = expire_time
        self.file_name = file_name
        self.url = url


class NotifyOrderRequest(BaseRequest):
    """
    订单支付状态回调通知

    :type notify_id: string
    :param notify_id: 通知 ID

    :type notify_time: string
    :param notify_time: 通知时间

    :type data: NotifyOrderData
    :param data: 返回数据
    """
    def __init__(
        self,
        notify_id=None,
        notify_time=None,
        data=None
    ):
        super().__init__()
        self.notify_id = notify_id
        self.notify_time = notify_time
        self.data = data


class NotifyOrderData(BaseRequest):
    """
    订单支付状态回调通知数据

    :type order_id: string
    :param order_id: 平台企业订单号

    :type pay: string
    :param pay: 订单金额

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type real_name: string
    :param real_name: 姓名

    :type card_no: string
    :param card_no: 收款人账号

    :type id_card: string
    :param id_card: 身份证号码

    :type phone_no: string
    :param phone_no: 手机号

    :type status: string
    :param status: 订单状态码

    :type status_detail: string
    :param status_detail: 订单详细状态码

    :type status_message: string
    :param status_message: 订单状态码描述

    :type status_detail_message: string
    :param status_detail_message: 订单详细状态码描述

    :type broker_amount: string
    :param broker_amount: 综合服务主体支付金额

    :type ref: string
    :param ref: 综合服务平台流水号

    :type broker_bank_bill: string
    :param broker_bank_bill: 支付交易流水号

    :type withdraw_platform: string
    :param withdraw_platform: 支付路径

    :type created_at: string
    :param created_at: 订单接收时间，精确到秒

    :type finished_time: string
    :param finished_time: 订单完成时间，精确到秒

    :type broker_fee: string
    :param broker_fee: 综合服务主体加成服务费

    :type broker_real_fee: string
    :param broker_real_fee: 余额账户支出加成服务费

    :type broker_deduct_fee: string
    :param broker_deduct_fee: 抵扣账户支出加成服务费

    :type pay_remark: string
    :param pay_remark: 订单备注

    :type user_fee: string
    :param user_fee: 用户加成服务费

    :type bank_name: string
    :param bank_name: 银行名称

    :type project_id: string
    :param project_id: 项目标识

    :type user_id: string
    :param user_id: 平台企业用户 ID
    """
    def __init__(
        self,
        order_id=None,
        pay=None,
        broker_id=None,
        dealer_id=None,
        real_name=None,
        card_no=None,
        id_card=None,
        phone_no=None,
        status=None,
        status_detail=None,
        status_message=None,
        status_detail_message=None,
        broker_amount=None,
        ref=None,
        broker_bank_bill=None,
        withdraw_platform=None,
        created_at=None,
        finished_time=None,
        broker_fee=None,
        broker_real_fee=None,
        broker_deduct_fee=None,
        pay_remark=None,
        user_fee=None,
        bank_name=None,
        project_id=None,
        user_id=None
    ):
        super().__init__()
        self.order_id = order_id
        self.pay = pay
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.real_name = real_name
        self.card_no = card_no
        self.id_card = id_card
        self.phone_no = phone_no
        self.status = status
        self.status_detail = status_detail
        self.status_message = status_message
        self.status_detail_message = status_detail_message
        self.broker_amount = broker_amount
        self.ref = ref
        self.broker_bank_bill = broker_bank_bill
        self.withdraw_platform = withdraw_platform
        self.created_at = created_at
        self.finished_time = finished_time
        self.broker_fee = broker_fee
        self.broker_real_fee = broker_real_fee
        self.broker_deduct_fee = broker_deduct_fee
        self.pay_remark = pay_remark
        self.user_fee = user_fee
        self.bank_name = bank_name
        self.project_id = project_id
        self.user_id = user_id


class CreateBatchOrderRequest(BaseRequest):
    """
    批量下单请求

    :type batch_id: string
    :param batch_id: 平台企业批次号

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type channel: string
    :param channel: 支付路径

    :type wx_app_id: string
    :param wx_app_id: 平台企业的微信 AppID

    :type total_pay: string
    :param total_pay: 订单总金额

    :type total_count: string
    :param total_count: 总笔数

    :type order_list: list
    :param order_list: 订单列表
    """
    def __init__(
        self,
        batch_id=None,
        dealer_id=None,
        broker_id=None,
        channel=None,
        wx_app_id=None,
        total_pay=None,
        total_count=None,
        order_list=None
    ):
        super().__init__()
        self.batch_id = batch_id
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.channel = channel
        self.wx_app_id = wx_app_id
        self.total_pay = total_pay
        self.total_count = total_count
        self.order_list = order_list


class BatchOrderInfo(BaseRequest):
    """
    批量下单订单信息

    :type order_id: string
    :param order_id: 平台企业订单号

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 身份证号码

    :type card_no: string
    :param card_no: 收款账号

    :type openid: string
    :param openid: 微信用户 openid

    :type phone_no: string
    :param phone_no: 手机号

    :type project_id: string
    :param project_id: 项目标识

    :type pay: string
    :param pay: 订单金额

    :type pay_remark: string
    :param pay_remark: 订单备注

    :type notify_url: string
    :param notify_url: 回调地址
    """
    def __init__(
        self,
        order_id=None,
        real_name=None,
        id_card=None,
        card_no=None,
        openid=None,
        phone_no=None,
        project_id=None,
        pay=None,
        pay_remark=None,
        notify_url=None
    ):
        super().__init__()
        self.order_id = order_id
        self.real_name = real_name
        self.id_card = id_card
        self.card_no = card_no
        self.openid = openid
        self.phone_no = phone_no
        self.project_id = project_id
        self.pay = pay
        self.pay_remark = pay_remark
        self.notify_url = notify_url


class CreateBatchOrderResponse(BaseRequest):
    """
    批量下单返回

    :type batch_id: string
    :param batch_id: 平台企业批次号

    :type result_list: list
    :param result_list: 订单结果列表
    """
    def __init__(
        self,
        batch_id=None,
        result_list=None
    ):
        super().__init__()
        self.batch_id = batch_id
        self.result_list = result_list


class BatchOrderResult(BaseRequest):
    """
    批量下单返回订单信息

    :type order_id: string
    :param order_id: 平台企业订单号

    :type ref: string
    :param ref: 综合服务平台流水号

    :type pay: string
    :param pay: 订单金额
    """
    def __init__(
        self,
        order_id=None,
        ref=None,
        pay=None
    ):
        super().__init__()
        self.order_id = order_id
        self.ref = ref
        self.pay = pay


class ConfirmBatchOrderRequest(BaseRequest):
    """
    批次确认请求

    :type batch_id: string
    :param batch_id: 平台企业批次号

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type channel: string
    :param channel: 支付路径
    """
    def __init__(
        self,
        batch_id=None,
        dealer_id=None,
        broker_id=None,
        channel=None
    ):
        super().__init__()
        self.batch_id = batch_id
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.channel = channel


class ConfirmBatchOrderResponse(BaseRequest):
    """
    批次确认响应
    """



"""发票开具"""

from ...base import BaseRequest


class GetInvoiceStatRequest(BaseRequest):
    """
    查询平台企业已开具和待开具发票金额请求

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type year: int
    :param year: 查询年份
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None,
        year=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.year = year


class GetInvoiceStatResponse(BaseRequest):
    """
    查询平台企业已开具和待开具发票金额返回

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type invoiced: string
    :param invoiced: 已开发票金额

    :type invoicing: string
    :param invoicing: 开票中发票金额

    :type not_invoiced: string
    :param not_invoiced: 待开发票金额
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None,
        invoiced=None,
        invoicing=None,
        not_invoiced=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.invoiced = invoiced
        self.invoicing = invoicing
        self.not_invoiced = not_invoiced


class GetInvoiceAmountRequest(BaseRequest):
    """
    查询可开具发票额度和发票开具信息请求

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id


class GetInvoiceAmountResponse(BaseRequest):
    """
    查询可开具发票额度和发票开具信息返回

    :type amount: string
    :param amount: 可开票额度

    :type bank_name_account: list
    :param bank_name_account: 系统支持的开户行及账号

    :type goods_services_name: list
    :param goods_services_name: 系统支持的货物或应税劳务、服务名称
    """
    def __init__(
        self,
        amount=None,
        bank_name_account=None,
        goods_services_name=None
    ):
        super().__init__()
        self.amount = amount
        self.bank_name_account = bank_name_account
        self.goods_services_name = goods_services_name


class ApplyInvoiceRequest(BaseRequest):
    """
    发票开具申请请求

    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type amount: string
    :param amount: 申请开票金额

    :type invoice_type: string
    :param invoice_type: 发票类型

    :type bank_name_account: string
    :param bank_name_account: 开户行及账号

    :type goods_services_name: string
    :param goods_services_name: 货物或应税劳务、服务名称

    :type remark: string
    :param remark: 发票备注
    """
    def __init__(
        self,
        invoice_apply_id=None,
        broker_id=None,
        dealer_id=None,
        amount=None,
        invoice_type=None,
        bank_name_account=None,
        goods_services_name=None,
        remark=None
    ):
        super().__init__()
        self.invoice_apply_id = invoice_apply_id
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.amount = amount
        self.invoice_type = invoice_type
        self.bank_name_account = bank_name_account
        self.goods_services_name = goods_services_name
        self.remark = remark


class ApplyInvoiceResponse(BaseRequest):
    """
    发票开具申请返回

    :type application_id: string
    :param application_id: 发票申请单 ID

    :type count: int
    :param count: 发票张数
    """
    def __init__(
        self,
        application_id=None,
        count=None
    ):
        super().__init__()
        self.application_id = application_id
        self.count = count


class GetInvoiceStatusRequest(BaseRequest):
    """
    查询发票开具申请状态请求

    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号

    :type application_id: string
    :param application_id: 发票申请单 ID
    """
    def __init__(
        self,
        invoice_apply_id=None,
        application_id=None
    ):
        super().__init__()
        self.invoice_apply_id = invoice_apply_id
        self.application_id = application_id


class GetInvoiceStatusResponse(BaseRequest):
    """
    查询发票开具申请状态返回

    :type status: string
    :param status: 申请结果

    :type count: int
    :param count: 发票张数

    :type price_tax_amount: string
    :param price_tax_amount: 价税合计

    :type price_amount: string
    :param price_amount: 不含税金额

    :type tax_amount: string
    :param tax_amount: 税额

    :type invoice_type: string
    :param invoice_type: 发票类型

    :type customer_name: string
    :param customer_name: 购方名称

    :type customer_tax_num: string
    :param customer_tax_num: 纳税人识别号

    :type customer_address_tel: string
    :param customer_address_tel: 购方地址、电话

    :type bank_name_account: string
    :param bank_name_account: 开户行及账号

    :type goods_services_name: string
    :param goods_services_name: 货物或应税劳务、服务名称

    :type remark: string
    :param remark: 发票备注

    :type post_type: string
    :param post_type: 邮寄类型

    :type waybill_number: list
    :param waybill_number: 快递单号
    """
    def __init__(
        self,
        status=None,
        count=None,
        price_tax_amount=None,
        price_amount=None,
        tax_amount=None,
        invoice_type=None,
        customer_name=None,
        customer_tax_num=None,
        customer_address_tel=None,
        bank_name_account=None,
        goods_services_name=None,
        remark=None,
        post_type=None,
        waybill_number=None
    ):
        super().__init__()
        self.status = status
        self.count = count
        self.price_tax_amount = price_tax_amount
        self.price_amount = price_amount
        self.tax_amount = tax_amount
        self.invoice_type = invoice_type
        self.customer_name = customer_name
        self.customer_tax_num = customer_tax_num
        self.customer_address_tel = customer_address_tel
        self.bank_name_account = bank_name_account
        self.goods_services_name = goods_services_name
        self.remark = remark
        self.post_type = post_type
        self.waybill_number = waybill_number


class GetInvoiceInformationRequest(BaseRequest):
    """
    查询发票信息请求

    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号

    :type application_id: string
    :param application_id: 发票申请单 ID
    """
    def __init__(
        self,
        invoice_apply_id=None,
        application_id=None
    ):
        super().__init__()
        self.invoice_apply_id = invoice_apply_id
        self.application_id = application_id


class GetInvoiceInformationResponse(BaseRequest):
    """
    查询发票信息返回

    :type information: list
    :param information: 发票信息
    """
    def __init__(
        self,
        information=None
    ):
        super().__init__()
        self.information = information


class InformationDataInfo(BaseRequest):
    """
    查询发票信息返回

    :type goods_services_name: string
    :param goods_services_name: 货物或应税劳务、服务名称

    :type invoice_num: string
    :param invoice_num: 发票号码

    :type invoice_code: string
    :param invoice_code: 发票代码

    :type price_amount: string
    :param price_amount: 不含税金额

    :type tax_amount: string
    :param tax_amount: 税额

    :type tax_rate: string
    :param tax_rate: 税率

    :type price_tax_amount: string
    :param price_tax_amount: 价税合计

    :type invoiced_date: string
    :param invoiced_date: 开票日期
    """
    def __init__(
        self,
        goods_services_name=None,
        invoice_num=None,
        invoice_code=None,
        price_amount=None,
        tax_amount=None,
        tax_rate=None,
        price_tax_amount=None,
        invoiced_date=None
    ):
        super().__init__()
        self.goods_services_name = goods_services_name
        self.invoice_num = invoice_num
        self.invoice_code = invoice_code
        self.price_amount = price_amount
        self.tax_amount = tax_amount
        self.tax_rate = tax_rate
        self.price_tax_amount = price_tax_amount
        self.invoiced_date = invoiced_date


class BankNameAccount(BaseRequest):
    """
    系统支持的开户行及账号

    :type item: string
    :param item: 开户行及账号

    :type default: bool
    :param default: 是否为默认值
    """
    def __init__(
        self,
        item=None,
        default=None
    ):
        super().__init__()
        self.item = item
        self.default = default


class GoodsServicesName(BaseRequest):
    """
    系统支持的货物或应税劳务、服务名称

    :type item: string
    :param item: 货物或应税劳务、服务名称

    :type default: bool
    :param default: 是否为默认值
    """
    def __init__(
        self,
        item=None,
        default=None
    ):
        super().__init__()
        self.item = item
        self.default = default


class GetInvoiceFileRequest(BaseRequest):
    """
    下载 PDF 版发票请求

    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号

    :type application_id: string
    :param application_id: 发票申请单 ID
    """
    def __init__(
        self,
        invoice_apply_id=None,
        application_id=None
    ):
        super().__init__()
        self.invoice_apply_id = invoice_apply_id
        self.application_id = application_id


class GetInvoiceFileResponse(BaseRequest):
    """
    下载 PDF 版发票返回

    :type url: string
    :param url: 下载地址

    :type name: string
    :param name: 文件名称
    """
    def __init__(
        self,
        url=None,
        name=None
    ):
        super().__init__()
        self.url = url
        self.name = name


class SendReminderEmailRequest(BaseRequest):
    """
    发送发票扫描件压缩包下载链接邮件请求

    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号

    :type application_id: string
    :param application_id: 发票申请单 ID
    """
    def __init__(
        self,
        invoice_apply_id=None,
        application_id=None
    ):
        super().__init__()
        self.invoice_apply_id = invoice_apply_id
        self.application_id = application_id


class SendReminderEmailResponse(BaseRequest):
    """
    发送发票扫描件压缩包下载链接邮件返回
    """


class NotifyInvoiceDoneRequest(BaseRequest):
    """
    发票开具完成通知

    :type application_id: string
    :param application_id: 发票申请单 ID

    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号

    :type status: string
    :param status: 申请结果

    :type count: int
    :param count: 发票张数

    :type price_tax_amount: string
    :param price_tax_amount: 价税合计

    :type price_amount: string
    :param price_amount: 不含税金额

    :type tax_amount: string
    :param tax_amount: 税额

    :type invoice_type: string
    :param invoice_type: 发票类型

    :type customer_name: string
    :param customer_name: 购方名称

    :type customer_tax_num: string
    :param customer_tax_num: 纳税人识别号

    :type customer_address_tel: string
    :param customer_address_tel: 购方地址、电话

    :type bank_name_account: string
    :param bank_name_account: 开户行及账号

    :type goods_services_name: string
    :param goods_services_name: 货物或应税劳务、服务名称

    :type remark: string
    :param remark: 发票备注

    :type post_type: string
    :param post_type: 邮寄类型

    :type waybill_number: list
    :param waybill_number: 快递单号

    :type reject_reason: string
    :param reject_reason: 驳回原因
    """
    def __init__(
        self,
        application_id=None,
        invoice_apply_id=None,
        status=None,
        count=None,
        price_tax_amount=None,
        price_amount=None,
        tax_amount=None,
        invoice_type=None,
        customer_name=None,
        customer_tax_num=None,
        customer_address_tel=None,
        bank_name_account=None,
        goods_services_name=None,
        remark=None,
        post_type=None,
        waybill_number=None,
        reject_reason=None
    ):
        super().__init__()
        self.application_id = application_id
        self.invoice_apply_id = invoice_apply_id
        self.status = status
        self.count = count
        self.price_tax_amount = price_tax_amount
        self.price_amount = price_amount
        self.tax_amount = tax_amount
        self.invoice_type = invoice_type
        self.customer_name = customer_name
        self.customer_tax_num = customer_tax_num
        self.customer_address_tel = customer_address_tel
        self.bank_name_account = bank_name_account
        self.goods_services_name = goods_services_name
        self.remark = remark
        self.post_type = post_type
        self.waybill_number = waybill_number
        self.reject_reason = reject_reason



"""发票开具"""

from .model.invoice import *
from ..base import BaseClient
from ...utils import Utils


class InvoiceClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)

    def get_invoice_stat(self, request: GetInvoiceStatRequest):
        """ 查询平台企业已开具和待开具发票金额

        :type request: GetInvoiceStatRequest
        :param request: the GetInvoiceStatRequest request parameters class.

        :return: GetInvoiceStatResponse
        """
        return self._get(
            "/api/payment/v1/invoice-stat",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_invoice_amount(self, request: GetInvoiceAmountRequest):
        """ 查询可开具发票额度和发票开具信息

        :type request: GetInvoiceAmountRequest
        :param request: the GetInvoiceAmountRequest request parameters class.

        :return: GetInvoiceAmountResponse
        """
        return self._post(
            "/api/invoice/v2/invoice-amount",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def apply_invoice(self, request: ApplyInvoiceRequest):
        """ 发票开具申请

        :type request: ApplyInvoiceRequest
        :param request: the ApplyInvoiceRequest request parameters class.

        :return: ApplyInvoiceResponse
        """
        return self._post(
            "/api/invoice/v2/apply",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_invoice_status(self, request: GetInvoiceStatusRequest):
        """ 查询发票开具申请状态

        :type request: GetInvoiceStatusRequest
        :param request: the GetInvoiceStatusRequest request parameters class.

        :return: GetInvoiceStatusResponse
        """
        return self._post(
            "/api/invoice/v2/invoice/invoice-status",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_invoice_information(self, request: GetInvoiceInformationRequest):
        """ 查询发票信息

        :type request: GetInvoiceInformationRequest
        :param request: the GetInvoiceInformationRequest request parameters class.

        :return: GetInvoiceInformationResponse
        """
        return self._post(
            "/api/invoice/v2/invoice-face-information",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_invoice_file(self, request: GetInvoiceFileRequest):
        """ 下载 PDF 版发票

        :type request: GetInvoiceFileRequest
        :param request: the GetInvoiceFileRequest request parameters class.

        :return: GetInvoiceFileResponse
        """
        return self._post(
            "/api/invoice/v2/invoice/invoice-pdf",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def send_reminder_email(self, request: SendReminderEmailRequest):
        """ 发送发票扫描件压缩包下载链接邮件

        :type request: SendReminderEmailRequest
        :param request: the SendReminderEmailRequest request parameters class.

        :return: SendReminderEmailResponse
        """
        return self._post(
            "/api/invoice/v2/invoice/reminder/email",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )



"""H5 签约"""

from ...base import BaseRequest


class H5UserPresignRequest(BaseRequest):
    """
    预申请签约请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 证件号码

    :type certificate_type: int
    :param certificate_type: 证件类型 0：身份证 2：港澳居民来往内地通行证 3：护照 5：台湾居民来往大陆通行证 9：港澳居民居住证 10：台湾居民居住证 11：外国人永久居留身份证 12：外国人工作许可证
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None,
        real_name=None,
        id_card=None,
        certificate_type=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.real_name = real_name
        self.id_card = id_card
        self.certificate_type = certificate_type


class H5UserPresignResponse(BaseRequest):
    """
    预申请签约返回

    :type uid: string
    :param uid: 用户 ID（废弃字段）

    :type token: string
    :param token: H5 签约 token

    :type status: int
    :param status: 签约状态
    """
    def __init__(
        self,
        uid=None,
        token=None,
        status=None
    ):
        super().__init__()
        self.uid = uid
        self.token = token
        self.status = status


class H5UserSignRequest(BaseRequest):
    """
    申请签约请求

    :type token: string
    :param token: H5 签约 token

    :type color: string
    :param color: H5 页面主题颜色

    :type url: string
    :param url: 回调 URL 地址

    :type redirect_url: string
    :param redirect_url: 跳转 URL
    """
    def __init__(
        self,
        token=None,
        color=None,
        url=None,
        redirect_url=None
    ):
        super().__init__()
        self.token = token
        self.color = color
        self.url = url
        self.redirect_url = redirect_url


class H5UserSignResponse(BaseRequest):
    """
    申请签约返回

    :type url: string
    :param url: H5 签约页面 URL
    """
    def __init__(
        self,
        url=None
    ):
        super().__init__()
        self.url = url


class GetH5UserSignStatusRequest(BaseRequest):
    """
    获取用户签约状态请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 证件号码
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None,
        real_name=None,
        id_card=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.real_name = real_name
        self.id_card = id_card


class GetH5UserSignStatusResponse(BaseRequest):
    """
    获取用户签约状态返回

    :type signed_at: string
    :param signed_at: 签约时间

    :type status: int
    :param status: 用户签约状态
    """
    def __init__(
        self,
        signed_at=None,
        status=None
    ):
        super().__init__()
        self.signed_at = signed_at
        self.status = status


class H5UserReleaseRequest(BaseRequest):
    """
    用户解约（测试账号专用接口）请求

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 证件号码

    :type certificate_type: int
    :param certificate_type: 证件类型 0：身份证 2：港澳居民来往内地通行证 3：护照 5：台湾居民来往大陆通行证 9：港澳居民居住证 10：台湾居民居住证 11：外国人永久居留身份证 12：外国人工作许可证
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None,
        real_name=None,
        id_card=None,
        certificate_type=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.real_name = real_name
        self.id_card = id_card
        self.certificate_type = certificate_type


class H5UserReleaseResponse(BaseRequest):
    """
    用户解约（测试账号专用接口）返回

    :type status: string
    :param status: 是否解约成功
    """
    def __init__(
        self,
        status=None
    ):
        super().__init__()
        self.status = status


class NotifyH5UserSignRequest(BaseRequest):
    """
    签约回调

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 证件号码

    :type phone: string
    :param phone: 预签约手机号
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None,
        real_name=None,
        id_card=None,
        phone=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.real_name = real_name
        self.id_card = id_card
        self.phone = phone



"""云账户新经济 H5"""

from .model.bizlicxjjh5 import *
from ..base import BaseClient
from ...utils import Utils


class BizlicXjjH5ServiceClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)

    def h5_get_start_url(self, request: H5GetStartUrlRequest):
        """ 预启动

        :type request: H5GetStartUrlRequest
        :param request: the H5GetStartUrlRequest request parameters class.

        :return: H5GetStartUrlResponse
        """
        return self._get(
            "/api/aic/new-economy/h5/v1/h5url",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def h5_eco_city_aic_status(self, request: H5EcoCityAicStatusRequest):
        """ 查询个体工商户状态

        :type request: H5EcoCityAicStatusRequest
        :param request: the H5EcoCityAicStatusRequest request parameters class.

        :return: H5EcoCityAicStatusResponse
        """
        return self._get(
            "/api/aic/new-economy/h5/v1/status",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )



"""API 签约"""

from .model.apiusersign import *
from ..base import BaseClient
from ...utils import Utils


class ApiUserSignServiceClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)

    def api_use_sign_contract(self, request: ApiUseSignContractRequest):
        """ 获取协议预览 URL

        :type request: ApiUseSignContractRequest
        :param request: the ApiUseSignContractRequest request parameters class.

        :return: ApiUseSignContractResponse
        """
        return self._get(
            "/api/sign/v1/user/contract",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def api_user_sign_contract(self, request: ApiUserSignContractRequest):
        """ 获取协议预览 URL V2

        :type request: ApiUserSignContractRequest
        :param request: the ApiUserSignContractRequest request parameters class.

        :return: ApiUserSignContractResponse
        """
        return self._get(
            "/api/sign/v1/user/contract",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def api_user_sign(self, request: ApiUserSignRequest):
        """ 用户签约

        :type request: ApiUserSignRequest
        :param request: the ApiUserSignRequest request parameters class.

        :return: ApiUserSignResponse
        """
        return self._post(
            "/api/sign/v1/user/sign",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_api_user_sign_status(self, request: GetApiUserSignStatusRequest):
        """ 获取用户签约状态

        :type request: GetApiUserSignStatusRequest
        :param request: the GetApiUserSignStatusRequest request parameters class.

        :return: GetApiUserSignStatusResponse
        """
        return self._get(
            "/api/sign/v1/user/status",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def api_user_sign_release(self, request: ApiUserSignReleaseRequest):
        """ 用户解约（测试账号专用接口）

        :type request: ApiUserSignReleaseRequest
        :param request: the ApiUserSignReleaseRequest request parameters class.

        :return: ApiUserSignReleaseResponse
        """
        return self._post(
            "/api/sign/v1/user/release",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )



"""H5 签约"""

from .model.h5usersign import *
from ..base import BaseClient
from ...utils import Utils


class H5UserSignServiceClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)

    def h5_user_presign(self, request: H5UserPresignRequest):
        """ 预申请签约

        :type request: H5UserPresignRequest
        :param request: the H5UserPresignRequest request parameters class.

        :return: H5UserPresignResponse
        """
        return self._post(
            "/api/sdk/v1/presign",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def h5_user_sign(self, request: H5UserSignRequest):
        """ 申请签约

        :type request: H5UserSignRequest
        :param request: the H5UserSignRequest request parameters class.

        :return: H5UserSignResponse
        """
        return self._get(
            "/api/sdk/v1/sign/h5",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_h5_user_sign_status(self, request: GetH5UserSignStatusRequest):
        """ 获取用户签约状态

        :type request: GetH5UserSignStatusRequest
        :param request: the GetH5UserSignStatusRequest request parameters class.

        :return: GetH5UserSignStatusResponse
        """
        return self._get(
            "/api/sdk/v1/sign/user/status",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def h5_user_release(self, request: H5UserReleaseRequest):
        """ 用户解约（测试账号专用接口）

        :type request: H5UserReleaseRequest
        :param request: the H5UserReleaseRequest request parameters class.

        :return: H5UserReleaseResponse
        """
        return self._post(
            "/api/sdk/v1/sign/release",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )



"""API 签约"""

from ...base import BaseRequest


class ApiUseSignContractRequest(BaseRequest):
    """
    获取协议预览 URL 请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id


class ApiUseSignContractResponse(BaseRequest):
    """
    获取协议预览 URL 返回

    :type url: string
    :param url: 预览跳转 URL

    :type title: string
    :param title: 协议名称
    """
    def __init__(
        self,
        url=None,
        title=None
    ):
        super().__init__()
        self.url = url
        self.title = title


class ApiUserSignContractRequest(BaseRequest):
    """
    获取协议预览 URL 请求 V2

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id


class ApiUserSignContractResponse(BaseRequest):
    """
    获取协议预览 URL 返回 V2

    :type url: string
    :param url: 预览跳转 URL

    :type title: string
    :param title: 协议名称
    """
    def __init__(
        self,
        url=None,
        title=None
    ):
        super().__init__()
        self.url = url
        self.title = title


class ApiUserSignRequest(BaseRequest):
    """
    用户签约请求

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 证件号码

    :type card_type: string
    :param card_type: 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None,
        real_name=None,
        id_card=None,
        card_type=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.real_name = real_name
        self.id_card = id_card
        self.card_type = card_type


class ApiUserSignResponse(BaseRequest):
    """
    用户签约返回

    :type status: string
    :param status: 是否签约成功
    """
    def __init__(
        self,
        status=None
    ):
        super().__init__()
        self.status = status


class GetApiUserSignStatusRequest(BaseRequest):
    """
    获取用户签约状态请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 证件号码
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None,
        real_name=None,
        id_card=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.real_name = real_name
        self.id_card = id_card


class GetApiUserSignStatusResponse(BaseRequest):
    """
    获取用户签约状态返回

    :type signed_at: string
    :param signed_at: 签约时间

    :type status: string
    :param status: 用户签约状态
    """
    def __init__(
        self,
        signed_at=None,
        status=None
    ):
        super().__init__()
        self.signed_at = signed_at
        self.status = status


class ApiUserSignReleaseRequest(BaseRequest):
    """
    用户解约（测试账号专用接口）请求

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type real_name: string
    :param real_name: 姓名

    :type id_card: string
    :param id_card: 证件号码

    :type card_type: string
    :param card_type: 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None,
        real_name=None,
        id_card=None,
        card_type=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.real_name = real_name
        self.id_card = id_card
        self.card_type = card_type


class ApiUserSignReleaseResponse(BaseRequest):
    """
    用户解约（测试账号专用接口）返回

    :type status: string
    :param status: 是否解约成功
    """
    def __init__(
        self,
        status=None
    ):
        super().__init__()
        self.status = status



"""用户信息验证"""

from .model.authentication import *
from ..base import BaseClient
from ...utils import Utils


class AuthenticationClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)

    def bank_card_four_auth_verify(self, request: BankCardFourAuthVerifyRequest):
        """ 银行卡四要素鉴权请求（下发短信验证码）

        :type request: BankCardFourAuthVerifyRequest
        :param request: the BankCardFourAuthVerifyRequest request parameters class.

        :return: BankCardFourAuthVerifyResponse
        """
        return self._post(
            "/authentication/verify-request",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def bank_card_four_auth_confirm(self, request: BankCardFourAuthConfirmRequest):
        """ 银行卡四要素确认请求（上传短信验证码）

        :type request: BankCardFourAuthConfirmRequest
        :param request: the BankCardFourAuthConfirmRequest request parameters class.

        :return: BankCardFourAuthConfirmResponse
        """
        return self._post(
            "/authentication/verify-confirm",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def bank_card_four_verify(self, request: BankCardFourVerifyRequest):
        """ 银行卡四要素验证

        :type request: BankCardFourVerifyRequest
        :param request: the BankCardFourVerifyRequest request parameters class.

        :return: BankCardFourVerifyResponse
        """
        return self._post(
            "/authentication/verify-bankcard-four-factor",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def bank_card_three_verify(self, request: BankCardThreeVerifyRequest):
        """ 银行卡三要素验证

        :type request: BankCardThreeVerifyRequest
        :param request: the BankCardThreeVerifyRequest request parameters class.

        :return: BankCardThreeVerifyResponse
        """
        return self._post(
            "/authentication/verify-bankcard-three-factor",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def id_card_verify(self, request: IDCardVerifyRequest):
        """ 身份证实名验证

        :type request: IDCardVerifyRequest
        :param request: the IDCardVerifyRequest request parameters class.

        :return: IDCardVerifyResponse
        """
        return self._post(
            "/authentication/verify-id",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def user_exempted_info(self, request: UserExemptedInfoRequest):
        """ 上传免验证用户名单信息

        :type request: UserExemptedInfoRequest
        :param request: the UserExemptedInfoRequest request parameters class.

        :return: UserExemptedInfoResponse
        """
        return self._post(
            "/api/payment/v1/user/exempted/info",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def user_white_check(self, request: UserWhiteCheckRequest):
        """ 查看免验证用户名单是否存在

        :type request: UserWhiteCheckRequest
        :param request: the UserWhiteCheckRequest request parameters class.

        :return: UserWhiteCheckResponse
        """
        return self._post(
            "/api/payment/v1/user/white/check",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_bank_card_info(self, request: GetBankCardInfoRequest):
        """ 银行卡信息查询接口

        :type request: GetBankCardInfoRequest
        :param request: the GetBankCardInfoRequest request parameters class.

        :return: GetBankCardInfoResponse
        """
        return self._get(
            "/api/payment/v1/card",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )



"""对账文件获取"""

from .model.dataservice import *
from ..base import BaseClient
from ...utils import Utils


class DataServiceClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)

    def list_daily_order(self, request: ListDailyOrderRequest):
        """ 查询日订单数据

        :type request: ListDailyOrderRequest
        :param request: the ListDailyOrderRequest request parameters class.

        :return: ListDailyOrderResponse
        """
        return self._get(
            "/api/dataservice/v1/orders",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_daily_order_file(self, request: GetDailyOrderFileRequest):
        """ 查询日订单文件

        :type request: GetDailyOrderFileRequest
        :param request: the GetDailyOrderFileRequest request parameters class.

        :return: GetDailyOrderFileResponse
        """
        return self._get(
            "/api/dataservice/v1/order/downloadurl",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_daily_order_file_v2(self, request: GetDailyOrderFileV2Request):
        """ 查询日订单文件（支付和退款订单）

        :type request: GetDailyOrderFileV2Request
        :param request: the GetDailyOrderFileV2Request request parameters class.

        :return: GetDailyOrderFileV2Response
        """
        return self._get(
            "/api/dataservice/v1/order/day/url",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def list_daily_bill(self, request: ListDailyBillRequest):
        """ 查询日流水数据

        :type request: ListDailyBillRequest
        :param request: the ListDailyBillRequest request parameters class.

        :return: ListDailyBillResponse
        """
        return self._get(
            "/api/dataservice/v1/bills",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def get_daily_bill_file_v2(self, request: GetDailyBillFileV2Request):
        """ 查询日流水文件

        :type request: GetDailyBillFileV2Request
        :param request: the GetDailyBillFileV2Request request parameters class.

        :return: GetDailyBillFileV2Response
        """
        return self._get(
            "/api/dataservice/v2/bill/downloadurl",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def list_dealer_recharge_record_v2(self, request: ListDealerRechargeRecordV2Request):
        """ 查询平台企业预付业务服务费记录

        :type request: ListDealerRechargeRecordV2Request
        :param request: the ListDealerRechargeRecordV2Request request parameters class.

        :return: ListDealerRechargeRecordV2Response
        """
        return self._get(
            "/api/dataservice/v2/recharge-record",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )

    def list_balance_daily_statement(self, request: ListBalanceDailyStatementRequest):
        """ 查询余额日账单数据

        :type request: ListBalanceDailyStatementRequest
        :param request: the ListBalanceDailyStatementRequest request parameters class.

        :return: ListBalanceDailyStatementResponse
        """
        return self._get(
            "/api/dataservice/v1/statements-daily",
            request.request_id,
            Utils.copy_dict(request.__dict__)
        )



"""对账文件获取"""

from ...base import BaseRequest


class GetDailyOrderFileRequest(BaseRequest):
    """
    查询日订单文件请求

    :type order_date: string
    :param order_date: 订单查询日期, 格式：yyyy-MM-dd
    """
    def __init__(
        self,
        order_date=None
    ):
        super().__init__()
        self.order_date = order_date


class GetDailyOrderFileResponse(BaseRequest):
    """
    查询日订单文件返回

    :type order_download_url: string
    :param order_download_url: 下载地址
    """
    def __init__(
        self,
        order_download_url=None
    ):
        super().__init__()
        self.order_download_url = order_download_url


class GetDailyBillFileV2Request(BaseRequest):
    """
    查询日流水文件请求

    :type bill_date: string
    :param bill_date: 所需获取的日流水日期，格式：yyyy-MM-dd
    """
    def __init__(
        self,
        bill_date=None
    ):
        super().__init__()
        self.bill_date = bill_date


class GetDailyBillFileV2Response(BaseRequest):
    """
    查询日流水文件返回

    :type bill_download_url: string
    :param bill_download_url: 下载地址
    """
    def __init__(
        self,
        bill_download_url=None
    ):
        super().__init__()
        self.bill_download_url = bill_download_url


class ListDealerRechargeRecordV2Request(BaseRequest):
    """
    平台企业预付业务服务费记录请求

    :type begin_at: string
    :param begin_at: 开始时间，格式：yyyy-MM-dd

    :type end_at: string
    :param end_at: 结束时间，格式：yyyy-MM-dd
    """
    def __init__(
        self,
        begin_at=None,
        end_at=None
    ):
        super().__init__()
        self.begin_at = begin_at
        self.end_at = end_at


class ListDealerRechargeRecordV2Response(BaseRequest):
    """
    平台企业预付业务服务费记录返回

    :type data: list
    :param data: 预付业务服务费记录
    """
    def __init__(
        self,
        data=None
    ):
        super().__init__()
        self.data = data


class RechargeRecordInfo(BaseRequest):
    """
    预付业务服务费记录信息

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type recharge_id: string
    :param recharge_id: 预付业务服务费记录 ID

    :type amount: string
    :param amount: 预付业务服务费

    :type actual_amount: string
    :param actual_amount: 实际到账金额

    :type created_at: string
    :param created_at: 创建时间

    :type recharge_channel: string
    :param recharge_channel: 资金用途

    :type remark: string
    :param remark: 预付业务服务费备注

    :type recharge_account_no: string
    :param recharge_account_no: 平台企业付款银行账号
    """
    def __init__(
        self,
        dealer_id=None,
        broker_id=None,
        recharge_id=None,
        amount=None,
        actual_amount=None,
        created_at=None,
        recharge_channel=None,
        remark=None,
        recharge_account_no=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.broker_id = broker_id
        self.recharge_id = recharge_id
        self.amount = amount
        self.actual_amount = actual_amount
        self.created_at = created_at
        self.recharge_channel = recharge_channel
        self.remark = remark
        self.recharge_account_no = recharge_account_no


class ListDailyOrderRequest(BaseRequest):
    """
    查询日订单数据请求

    :type order_date: string
    :param order_date: 订单查询日期, 格式：yyyy-MM-dd格式：yyyy-MM-dd

    :type offset: int
    :param offset: 偏移量

    :type length: int
    :param length: 长度

    :type channel: string
    :param channel: 支付路径名，银行卡（默认）、支付宝、微信

    :type data_type: string
    :param data_type: 如果为 encryption，则对返回的 data 进行加密
    """
    def __init__(
        self,
        order_date=None,
        offset=None,
        length=None,
        channel=None,
        data_type=None
    ):
        super().__init__()
        self.order_date = order_date
        self.offset = offset
        self.length = length
        self.channel = channel
        self.data_type = data_type


class ListDailyOrderResponse(BaseRequest):
    """
    查询日订单数据返回

    :type total_num: int
    :param total_num: 总数目

    :type list: list
    :param list: 条目信息
    """
    def __init__(
        self,
        total_num=None,
        list=None
    ):
        super().__init__()
        self.total_num = total_num
        self.list = list


class DealerOrderInfo(BaseRequest):
    """
    平台企业支付订单信息

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type order_id: string
    :param order_id: 平台企业订单号

    :type ref: string
    :param ref: 订单流水号

    :type batch_id: string
    :param batch_id: 批次ID

    :type real_name: string
    :param real_name: 姓名

    :type card_no: string
    :param card_no: 收款账号

    :type broker_amount: string
    :param broker_amount: 综合服务主体订单金额

    :type broker_fee: string
    :param broker_fee: 综合服务主体加成服务费

    :type bill: string
    :param bill: 支付路径流水号

    :type status: string
    :param status: 订单状态

    :type status_message: string
    :param status_message: 订单状态码描述

    :type status_detail: string
    :param status_detail: 订单详情

    :type status_detail_message: string
    :param status_detail_message: 订单详细状态码描述

    :type statement_id: string
    :param statement_id: 短周期授信账单号

    :type fee_statement_id: string
    :param fee_statement_id: 服务费账单号

    :type bal_statement_id: string
    :param bal_statement_id: 余额账单号

    :type channel: string
    :param channel: 支付路径

    :type created_at: string
    :param created_at: 创建时间

    :type finished_time: string
    :param finished_time: 完成时间
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None,
        order_id=None,
        ref=None,
        batch_id=None,
        real_name=None,
        card_no=None,
        broker_amount=None,
        broker_fee=None,
        bill=None,
        status=None,
        status_message=None,
        status_detail=None,
        status_detail_message=None,
        statement_id=None,
        fee_statement_id=None,
        bal_statement_id=None,
        channel=None,
        created_at=None,
        finished_time=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.order_id = order_id
        self.ref = ref
        self.batch_id = batch_id
        self.real_name = real_name
        self.card_no = card_no
        self.broker_amount = broker_amount
        self.broker_fee = broker_fee
        self.bill = bill
        self.status = status
        self.status_message = status_message
        self.status_detail = status_detail
        self.status_detail_message = status_detail_message
        self.statement_id = statement_id
        self.fee_statement_id = fee_statement_id
        self.bal_statement_id = bal_statement_id
        self.channel = channel
        self.created_at = created_at
        self.finished_time = finished_time


class ListDailyBillRequest(BaseRequest):
    """
    查询日流水数据请求

    :type bill_date: string
    :param bill_date: 流水查询日期

    :type offset: int
    :param offset: 偏移量

    :type length: int
    :param length: 长度

    :type data_type: string
    :param data_type: 如果为 encryption，则对返回的 data 进行加密
    """
    def __init__(
        self,
        bill_date=None,
        offset=None,
        length=None,
        data_type=None
    ):
        super().__init__()
        self.bill_date = bill_date
        self.offset = offset
        self.length = length
        self.data_type = data_type


class ListDailyBillResponse(BaseRequest):
    """
    查询日流水数据返回

    :type total_num: int
    :param total_num: 总条数

    :type list: list
    :param list: 条目信息
    """
    def __init__(
        self,
        total_num=None,
        list=None
    ):
        super().__init__()
        self.total_num = total_num
        self.list = list


class DealerBillInfo(BaseRequest):
    """
    流水详情

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type order_id: string
    :param order_id: 平台企业订单号

    :type ref: string
    :param ref: 资金流水号

    :type broker_product_name: string
    :param broker_product_name: 综合服务主体名称

    :type dealer_product_name: string
    :param dealer_product_name: 平台企业名称

    :type biz_ref: string
    :param biz_ref: 业务订单流水号

    :type acct_type: string
    :param acct_type: 账户类型

    :type amount: string
    :param amount: 入账金额

    :type balance: string
    :param balance: 账户余额

    :type business_category: string
    :param business_category: 业务分类

    :type business_type: string
    :param business_type: 业务类型

    :type consumption_type: string
    :param consumption_type: 收支类型

    :type created_at: string
    :param created_at: 入账时间

    :type remark: string
    :param remark: 备注
    """
    def __init__(
        self,
        broker_id=None,
        dealer_id=None,
        order_id=None,
        ref=None,
        broker_product_name=None,
        dealer_product_name=None,
        biz_ref=None,
        acct_type=None,
        amount=None,
        balance=None,
        business_category=None,
        business_type=None,
        consumption_type=None,
        created_at=None,
        remark=None
    ):
        super().__init__()
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.order_id = order_id
        self.ref = ref
        self.broker_product_name = broker_product_name
        self.dealer_product_name = dealer_product_name
        self.biz_ref = biz_ref
        self.acct_type = acct_type
        self.amount = amount
        self.balance = balance
        self.business_category = business_category
        self.business_type = business_type
        self.consumption_type = consumption_type
        self.created_at = created_at
        self.remark = remark


class GetDailyOrderFileV2Request(BaseRequest):
    """
    查询日订单文件（支付和退款订单）请求

    :type order_date: string
    :param order_date: 订单查询日期, 格式：yyyy-MM-dd
    """
    def __init__(
        self,
        order_date=None
    ):
        super().__init__()
        self.order_date = order_date


class GetDailyOrderFileV2Response(BaseRequest):
    """
    查询日订单文件（支付和退款订单）返回

    :type url: string
    :param url: 下载地址
    """
    def __init__(
        self,
        url=None
    ):
        super().__init__()
        self.url = url


class ListBalanceDailyStatementRequest(BaseRequest):
    """
    查询余额日账单数据请求

    :type statement_date: string
    :param statement_date: 账单查询日期 格式：yyyy-MM-dd
    """
    def __init__(
        self,
        statement_date=None
    ):
        super().__init__()
        self.statement_date = statement_date


class ListBalanceDailyStatementResponse(BaseRequest):
    """
    查询余额日账单数据返回

    :type list: list
    :param list: 条目信息
    """
    def __init__(
        self,
        list=None
    ):
        super().__init__()
        self.list = list


class StatementDetail(BaseRequest):
    """
    余额账单信息详情

    :type statement_id: string
    :param statement_id: 账单 ID

    :type statement_date: string
    :param statement_date: 账单日期

    :type broker_id: string
    :param broker_id: 综合服务主体 ID

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type broker_product_name: string
    :param broker_product_name: 综合服务主体名称

    :type dealer_product_name: string
    :param dealer_product_name: 平台企业名称

    :type biz_type: string
    :param biz_type: 业务类型

    :type total_money: string
    :param total_money: 账单金额

    :type amount: string
    :param amount: 订单金额

    :type reex_amount: string
    :param reex_amount: 退汇金额

    :type fee_amount: string
    :param fee_amount: 加成服务费金额

    :type deduct_rebate_fee_amount: string
    :param deduct_rebate_fee_amount: 加成服务费抵扣金额

    :type money_adjust: string
    :param money_adjust: 冲补金额

    :type status: string
    :param status: 账单状态

    :type invoice_status: string
    :param invoice_status: 开票状态

    :type project_id: string
    :param project_id: 项目 ID

    :type project_name: string
    :param project_name: 项目名称
    """
    def __init__(
        self,
        statement_id=None,
        statement_date=None,
        broker_id=None,
        dealer_id=None,
        broker_product_name=None,
        dealer_product_name=None,
        biz_type=None,
        total_money=None,
        amount=None,
        reex_amount=None,
        fee_amount=None,
        deduct_rebate_fee_amount=None,
        money_adjust=None,
        status=None,
        invoice_status=None,
        project_id=None,
        project_name=None
    ):
        super().__init__()
        self.statement_id = statement_id
        self.statement_date = statement_date
        self.broker_id = broker_id
        self.dealer_id = dealer_id
        self.broker_product_name = broker_product_name
        self.dealer_product_name = dealer_product_name
        self.biz_type = biz_type
        self.total_money = total_money
        self.amount = amount
        self.reex_amount = reex_amount
        self.fee_amount = fee_amount
        self.deduct_rebate_fee_amount = deduct_rebate_fee_amount
        self.money_adjust = money_adjust
        self.status = status
        self.invoice_status = invoice_status
        self.project_id = project_id
        self.project_name = project_name



"""个人所得税扣缴明细表"""

from ...base import BaseRequest


class GetTaxFileRequest(BaseRequest):
    """
    下载个人所得税扣缴明细表请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type ent_id: string
    :param ent_id: 平台企业签约主体

    :type year_month: string
    :param year_month: 所属期
    """
    def __init__(
        self,
        dealer_id=None,
        ent_id=None,
        year_month=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.ent_id = ent_id
        self.year_month = year_month


class GetTaxFileResponse(BaseRequest):
    """
    下载个人所得税扣缴明细表返回

    :type file_info: list
    :param file_info: 文件详情
    """
    def __init__(
        self,
        file_info=None
    ):
        super().__init__()
        self.file_info = file_info


class FileInfo(BaseRequest):
    """
    报税文件详情

    :type name: string
    :param name: 文件名称

    :type url: string
    :param url: 下载文件临时 URL

    :type pwd: string
    :param pwd: 文件解压缩密码
    """
    def __init__(
        self,
        name=None,
        url=None,
        pwd=None
    ):
        super().__init__()
        self.name = name
        self.url = url
        self.pwd = pwd


class GetUserCrossRequest(BaseRequest):
    """
    查询纳税人是否为跨集团用户请求

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type year: string
    :param year: 年份

    :type id_card: string
    :param id_card: 身份证号码

    :type ent_id: string
    :param ent_id: 平台企业签约主体
    """
    def __init__(
        self,
        dealer_id=None,
        year=None,
        id_card=None,
        ent_id=None
    ):
        super().__init__()
        self.dealer_id = dealer_id
        self.year = year
        self.id_card = id_card
        self.ent_id = ent_id


class GetUserCrossResponse(BaseRequest):
    """
    查询纳税人是否为跨集团用户返回

    :type is_cross: bool
    :param is_cross: 跨集团标识
    """
    def __init__(
        self,
        is_cross=None
    ):
        super().__init__()
        self.is_cross = is_cross
